==> widgetTools_1.16.0.zip: widgetTools/doc/widgetTools.R <==
###################################################
### chunk number 1: 
###################################################
library(widgetTools)
PWEnv <- new.env(hash = TRUE, parent = parent.frame(1))


###################################################
### chunk number 2: 
###################################################
label1 <- label(wName = "label1", wValue = "File Name: ", wEnv = PWEnv)
entry1 <- entryBox(wName = "entry1", wValue = "Feed me using browse",
                   wEnv = PWEnv)
browse2Entry1 <- function(){
    tempValue <- tclvalue(tkgetOpenFile())
    temp <- get(wName(entry1), env = PWEnv)
    wValue(temp) <- paste(tempValue, sep = "", collapse = ";")
    assign(wName(entry1), temp, env = PWEnv)
}
button1 <- button(wName = "button1", wValue = "Browse",
                     wFuns = list(command = browse2Entry1), wEnv = PWEnv)
list1 <- listBox(wName = "list1", wValue = c(Option1 = TRUE, Option2 = FALSE,
                                 Option3 = FALSE), wEnv = PWEnv)
text1 <- textBox(wName = "text1", wValue = "Feed me something",
                 wEnv = PWEnv)
label2 <- label(wName = "label2", wValue = "Select one:  ", wEnv = PWEnv)
radios1 <- radioButton(wName = "radios1", wValue = c(radio1 = TRUE,
                       radio2 = FALSE, radio3 = FALSE), wEnv = PWEnv)
label3 <- label(wName = "label3", wValue = "Select one to many: ",
                wEnv = PWEnv)
checks1 <- checkButton(wName = "checks1", wValue = c(check1 = TRUE,
                       check22 = FALSE, check3 = FALSE), wEnv = PWEnv)


###################################################
### chunk number 3: 
###################################################
wName(label1)
wName(label1) <- "YYY"
wName(label1)
wName(label1) <- "label1"


###################################################
### chunk number 4: 
###################################################
pWidgets <- list(topRow = list(label1 = label1, entry1 = entry1,
                 button1 = button1), textRow = list(list1 = list1,
                 text1 = text1), radGroup = list(label2 = label2,
                 radios1 = radios1), chkGroup = list(label3 = label3,
                                     checks1 = checks1))


###################################################
### chunk number 5: 
###################################################
if(interactive()){
aWidget <- widget(wTitle = "A test widget", pWidgets, funs = list(),
                 preFun = function() print("Hello"),
                 postFun = function() print("Bye"), env = PWEnv)
}


###################################################
### chunk number 6: 
###################################################
if(interactive()){
wValue(pWidgets(aWidget)[["topRow"]][["entry1"]])
wValue(pWidgets(aWidget)[["textRow"]][["list1"]])
wValue(pWidgets(aWidget)[["textRow"]][["text1"]])
wValue(pWidgets(aWidget)[["radGroup"]][["radios1"]])
wValue(pWidgets(aWidget)[["chkGroup"]][["checks1"]])
}

==> widgetTools_1.28.0.zip: widgetTools/doc/widgetTools.R <==
###################################################
### chunk number 1: 
###################################################
#line 112 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHnRejP/R.INSTALL16637a1c/widgetTools/inst/doc/widgetTools.Rnw"
library(widgetTools)
PWEnv <- new.env(hash = TRUE, parent = parent.frame(1))


###################################################
### chunk number 2: 
###################################################
#line 171 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHnRejP/R.INSTALL16637a1c/widgetTools/inst/doc/widgetTools.Rnw"
label1 <- label(wName = "label1", wValue = "File Name: ", wEnv = PWEnv)
entry1 <- entryBox(wName = "entry1", wValue = "Feed me using browse",
                   wEnv = PWEnv)
browse2Entry1 <- function(){
    tempValue <- tclvalue(tkgetOpenFile())
    temp <- get(wName(entry1), env = PWEnv)
    wValue(temp) <- paste(tempValue, sep = "", collapse = ";")
    assign(wName(entry1), temp, env = PWEnv)
}
button1 <- button(wName = "button1", wValue = "Browse",
                     wFuns = list(command = browse2Entry1), wEnv = PWEnv)
list1 <- listBox(wName = "list1", wValue = c(Option1 = TRUE, Option2 = FALSE,
                                 Option3 = FALSE), wEnv = PWEnv)
text1 <- textBox(wName = "text1", wValue = "Feed me something",
                 wEnv = PWEnv)
label2 <- label(wName = "label2", wValue = "Select one:  ", wEnv = PWEnv)
radios1 <- radioButton(wName = "radios1", wValue = c(radio1 = TRUE,
                       radio2 = FALSE, radio3 = FALSE), wEnv = PWEnv)
label3 <- label(wName = "label3", wValue = "Select one to many: ",
                wEnv = PWEnv)
checks1 <- checkButton(wName = "checks1", wValue = c(check1 = TRUE,
                       check22 = FALSE, check3 = FALSE), wEnv = PWEnv)


###################################################
### chunk number 3: 
###################################################
#line 233 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHnRejP/R.INSTALL16637a1c/widgetTools/inst/doc/widgetTools.Rnw"
wName(label1)
wName(label1) <- "YYY"
wName(label1)
wName(label1) <- "label1"


###################################################
### chunk number 4: 
###################################################
#line 252 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHnRejP/R.INSTALL16637a1c/widgetTools/inst/doc/widgetTools.Rnw"
pWidgets <- list(topRow = list(label1 = label1, entry1 = entry1,
                 button1 = button1), textRow = list(list1 = list1,
                 text1 = text1), radGroup = list(label2 = label2,
                 radios1 = radios1), chkGroup = list(label3 = label3,
                                     checks1 = checks1))


###################################################
### chunk number 5: 
###################################################
#line 304 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHnRejP/R.INSTALL16637a1c/widgetTools/inst/doc/widgetTools.Rnw"
if(interactive()){
aWidget <- widget(wTitle = "A test widget", pWidgets, funs = list(),
                 preFun = function() print("Hello"),
                 postFun = function() print("Bye"), env = PWEnv)
}


###################################################
### chunk number 6: 
###################################################
#line 329 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHnRejP/R.INSTALL16637a1c/widgetTools/inst/doc/widgetTools.Rnw"
if(interactive()){
wValue(pWidgets(aWidget)[["topRow"]][["entry1"]])
wValue(pWidgets(aWidget)[["textRow"]][["list1"]])
wValue(pWidgets(aWidget)[["textRow"]][["text1"]])
wValue(pWidgets(aWidget)[["radGroup"]][["radios1"]])
wValue(pWidgets(aWidget)[["chkGroup"]][["checks1"]])
}
